@@ -28,6 +28,8 @@ def setdefault_name(source_file, config):
 
 setdefault_name.defaults = {
     'rename_extensions': {
+        '.ply': u'.html',
+        '.plywood': u'.html',
         '.j2': u'.html',
         '.jinja2': u'.html',
         '.jinja': u'.html',
