@@ -18,31 +18,31 @@ class ImageNode(AssetNode):
     The thumbnails are available as image_node.{thumbnail_name}
     """
     def generate_file(self, site, source_path, target_path):
-        if 'size' in self.config:
-            if not self['skip']:
-                image = Image.open(source_path)
-                size = self.config['size']
+        # if 'size' in self.config:
+        #     if not self['skip']:
+        #         image = Image.open(source_path)
+        #         size = self.config['size']
 
-                if isinstance(size, basestring):
-                    size = self.config['size'].split('x')
-                    if len(size) == 1:
-                        size = [size[0], size[0]]
-                elif isinstance(size, int):
-                    size = [size, size]
+        #         if isinstance(size, basestring):
+        #             size = self.config['size'].split('x')
+        #             if len(size) == 1:
+        #                 size = [size[0], size[0]]
+        #         elif isinstance(size, int):
+        #             size = [size, size]
 
-                # ensure working with ints - strings do nothing in PIL (no
-                # error, nothing!)
-                size[0] = int(size[0])
-                size[1] = int(size[1])
-                image.thumbnail(size, Image.ANTIALIAS)
-                image.save(target_path)
-            elif self['__verbose']:
-                sys.stderr.write("Skipping %s\n" % target_path)
-        else:
-            if not self['skip']:
-                copy2(source_path, target_path)
-            elif self['__verbose']:
-                sys.stderr.write("Skipping %s\n" % target_path)
+        #         # ensure working with ints - strings do nothing in PIL (no
+        #         # error, nothing!)
+        #         size[0] = int(size[0])
+        #         size[1] = int(size[1])
+        #         image.thumbnail(size, Image.ANTIALIAS)
+        #         image.save(target_path)
+        #     elif self['__verbose']:
+        #         sys.stderr.write("Skipping %s\n" % target_path)
+        # else:
+        #     if not self['skip']:
+        #         copy2(source_path, target_path)
+        #     elif self['__verbose']:
+        #         sys.stderr.write("Skipping %s\n" % target_path)
         self.files_tracked.append(source_path)
         self.files_written.append(target_path)
 
@@ -93,4 +93,5 @@ def processor(config, source_path, target_path):
     return (image_node, ) + tuple(thumbs)
 
 Registry.register('image', processor)
-Registry.associate('image', ['*.png', '*.jpg', '*.jpeg', '*.gif'])
+Registry.associate('image', ['*.png', '*.jpg', '*.jpeg', '*.gif',
+                             '*.PNG', '*.JPG', '*.JPEG', '*.GIF'])
